@@ -5,6 +5,7 @@ from luminesce.api.application_metadata_api import ApplicationMetadataApi
 from luminesce.api.binary_downloading_api import BinaryDownloadingApi
 from luminesce.api.certificate_management_api import CertificateManagementApi
 from luminesce.api.current_table_field_catalog_api import CurrentTableFieldCatalogApi
+from luminesce.api.health_checking_endpoint_api import HealthCheckingEndpointApi
 from luminesce.api.historically_executed_queries_api import HistoricallyExecutedQueriesApi
 from luminesce.api.multi_query_execution_api import MultiQueryExecutionApi
 from luminesce.api.sql_background_execution_api import SqlBackgroundExecutionApi
@@ -17,6 +18,7 @@ __all__ = [
     "BinaryDownloadingApi",
     "CertificateManagementApi",
     "CurrentTableFieldCatalogApi",
+    "HealthCheckingEndpointApi",
     "HistoricallyExecutedQueriesApi",
     "MultiQueryExecutionApi",
     "SqlBackgroundExecutionApi",
